========
bibscrap
========

.. image:: https://img.shields.io/pypi/v/bibscrap?style=flat
   :target: https://pypi.org/project/bibscrap/
   :alt: PyPI version

.. image:: https://app.travis-ci.com/cotterell/bibscrap.svg
   :target: https://app.travis-ci.com/cotterell/bibscrap

.. image:: https://readthedocs.org/projects/bibscrap/badge/?version=latest
   :target: https://bibscrap.readthedocs.io/en/latest/
   :alt: bibscrap's documentation


.. image:: https://codecov.io/gh/cotterell/bibscrap/branch/main/graph/badge.svg?token=TQQWS0OQ0E
   :target: https://codecov.io/gh/cotterell/bibscrap
   :alt: Code coverage

.. image:: https://img.shields.io/pypi/l/bibscrap.svg
   :target: https://github.com/cotterell/bibscrap/blob/master/LICENSE.rst
   :alt: MIT license

.. image:: https://img.shields.io/badge/code%20style-black-161b22.svg
   :target: https://github.com/psf/black
   :alt: Code style: black

Overview
========

The **bibscrap** package provides semi-automated tools for systematic literature reviews.

Requirements
============

* Python 3.9+

Install
=======

To install Bibscrap using **pipenv**::

  $ pipenv install --pre bibscrap

To install Bibscrap using **pip**::

  $ pip install --pre bibscrap

Documentation
=============

Documentation is available online at https://bibscrap.readthedocs.io/ and in the
``docs`` directory.

Contributors: Getting Started
=============================

To download the development version of **bibscrap**, follow the instructions
provided below::

  $ git clone https://github.com/cotterell/bibscrap.git
  $ cd bibscrap
  $ poetry install -v

If you are part of the **bibscrap** development team, then you should also
install the development packages::

  $ pre-commit install

Contributors
============

=====================  ==========================================================  ============
Contributor            GitHub                                                      Role
=====================  ==========================================================  ============
Aidan Killer           `@aikill <https://github.com/aikill>`_                      Developer
Jack Solomon           `@jbs26156 <https://github.com/jbs26156>`_                  Developer
Matthew Pooser         `@mpooser <https://github.com/mpooser>`_                    Developer
Michael E. Cotterell   `@mepcotterell <https://github.com/mepcotterell>`_          Maintainer
Mitchell Casleton      `@MitchellCasleton <https://github.com/MitchellCasleton>`_  Developer
My Nguyen              `@mynguyen0628 <https://github.com/mynguyen0628>`_          Developer
=====================  ==========================================================  ============
